@@ -42,6 +42,7 @@ from google.cloud.dataflow_v1beta3.types import environment, jobs, templates
 from .transports.base import DEFAULT_CLIENT_INFO, TemplatesServiceTransport
 from .transports.grpc import TemplatesServiceGrpcTransport
 from .transports.grpc_asyncio import TemplatesServiceGrpcAsyncIOTransport
+from .transports.rest import TemplatesServiceRestTransport
 
 
 class TemplatesServiceClientMeta(type):
@@ -57,6 +58,7 @@ class TemplatesServiceClientMeta(type):
     )  # type: Dict[str, Type[TemplatesServiceTransport]]
     _transport_registry["grpc"] = TemplatesServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = TemplatesServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = TemplatesServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -330,6 +332,9 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
             transport (Union[str, TemplatesServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -422,6 +427,13 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_create_job_from_template():
@@ -501,6 +513,13 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_launch_template():
@@ -579,6 +598,13 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataflow_v1beta3
 
             def sample_get_template():
